function [Fl, Wy, Lc, La, Iref, Iarm, Rarm] = load_thompson(sim, turns)
% [Fl, Wy, Lc, La, Iref, Iarm, Rarm] = load_thompson(sim, turns)
%
% loads a magnetic simulation of lorentz repulsion.

% lorentz force
Fl=dlmread(strcat(sim, '/Fl_cf_pos.txt'));

% volume integral of B: T.m^3
By=dlmread(strcat(sim, '/By_cf_pos.txt'));

% L.i^2
AJ=dlmread(strcat(sim, '/L_cf_pos.txt'));

% armature height, width, coil J, armature J
params=dlmread(strcat(sim, '/params.txt'));
aheight=params(1);
awidth=params(2);
Jcoil=params(3);
Jarm=params(4);

% flux linkage thru armature with test current
Wy=By/(aheight*1e-3);

% mm^2, common to all models
coil_area=12*24;

% reference current/turn in coil; inductance thereof
Iref=Jcoil*coil_area/turns;
Lc=AJ/(Iref*Iref);

% armature test current; inductance
Iarm=aheight*awidth*Jarm;
AJ=dlmread(strcat(sim, '/L_armature.txt'));
La=AJ/(Iarm*Iarm);

% armature power, tells us resistance (P=I^2.R)
Pa=dlmread(strcat(sim, '/P_armature.txt'));
Rarm=Pa/(Iarm*Iarm);

