function [t, Ic, Ia, V, F, vel] = run_thompson(R, C, V0, geom, turns, dt, steps, mass)
%	[t, Ic, Ia, V, F, vel] = run_thompson(R, C, V0, geom, turns, dt, steps, mass)
%
% Run thompson simulation
%
% t = time series
% Ic = coil I
% Ia = armature I
% V = capacitor voltage
% vel = armature velocity
%
% R = resistance
% C = capacitance
% V0 = cap charge
% geom = geometry simulation directory
% turns in coil
% dt = time step
% steps = step count


[Fl, Wy, Lcoil, Larm, Ic0, Ia0, Rarm]=load_thompson(geom, turns);
rlc=rlc_init(R, C, V0);

time=0;
Icoil=rlc(4);
Iarm=0;
pos=0;
spd=0;
W=0;	% since Icoil=0
force=0;

% extrapolate flux coupling over longer distance (its a straight line down)
Wsamp=length(Wy);
Wslope=(Wy(Wsamp)-Wy(20))/(Wsamp-20);
for n=Wsamp+1:500
   Wy(n)=Wy(n-1)+Wslope;
end

for n=1:steps
   t(n)=time;
   Ic(n)=Icoil;
   Ia(n)=Iarm;
   V(n)=rlc(3);
   vel(n)=spd;
   F(n)=force;
   
   time=time+dt;
   if pos < 0
      disp(strcat('run returns at step', num2str(n)));
      return;
   end
   
   L=maginterp(Lcoil, pos);		% sim discharge
   rlc=rlc_step(rlc, L, dt);
   Icoil=rlc(4);
   
   % new flux thru armature
   W2=maginterp(Wy, pos)*Icoil/Ic0;
   dw=W2-W;
   W=W2;
	
   % simulate current in armature
   La=maginterp(Larm, pos);
   Iarm=lr_step(Iarm, La, Rarm, dt, -dw/dt);
   
   % lorentz force
   force=maginterp(Fl, pos)*Icoil*Iarm/(Ic0*Ia0);
   
   % motion
   spd=spd+dt*force/mass;
	pos=pos+spd*dt;
end
